[Emu] Changes default OpenFlow port to 6653. Remove trailing spaces.

Change-Id: Iebb2f8bc115efeb88f26b109eb93650bda7ce2fd
diff --git a/TestON/drivers/common/cli/emulator/remotemininetdriver.py b/TestON/drivers/common/cli/emulator/remotemininetdriver.py
index 6b7197f..f03dc27 100644
--- a/TestON/drivers/common/cli/emulator/remotemininetdriver.py
+++ b/TestON/drivers/common/cli/emulator/remotemininetdriver.py
@@ -294,7 +294,7 @@
             self,
             filename,
             intf="eth0",
-            port="port 6633",
+            port="port 6653",
             user="admin" ):
         """
         Runs tcpdump on an interface and saves the file
diff --git a/TestON/drivers/common/cli/emulator/mininetclidriver.py b/TestON/drivers/common/cli/emulator/mininetclidriver.py
index 1d75ae4..7a4605c 100644
--- a/TestON/drivers/common/cli/emulator/mininetclidriver.py
+++ b/TestON/drivers/common/cli/emulator/mininetclidriver.py
@@ -1330,7 +1330,7 @@
             main.cleanup()
             main.exit()
 
-    def assignSwController( self, sw, ip, port="6633", ptcp="" ):
+    def assignSwController( self, sw, ip, port="6653", ptcp="" ):
         """
         Description:
             Assign switches to the controllers ( for ovs use only )
@@ -1338,8 +1338,8 @@
             sw - Name of the switch. This can be a list or a string.
             ip - Ip addresses of controllers. This can be a list or a string.
         Optional:
             port - ONOS use port 6633, if no list of ports is passed, then
                    the all the controller will use 6633 as their port number
             ptcp - ptcp number, This can be a string or a list that has
                    the same length as switch. This is optional and not required
                    when using ovs switches.
@@ -1893,7 +1893,7 @@
             main.log.info( flow2 )
             return main.FALSE
 
-    def startTcpdump( self, filename, intf="eth0", port="port 6633" ):
+    def startTcpdump( self, filename, intf="eth0", port="port 6653" ):
         """
            Runs tpdump on an interface and saves the file
            intf can be specified, or the default eth0 is used"""
@@ -1338,8 +1338,8 @@
             ip - Ip addresses of controllers. This can be a list or a string.
         Optional:
-            port - ONOS use port 6633, if no list of ports is passed, then
-                   the all the controller will use 6633 as their port number
+            port - ONOS use port 6653, if no list of ports is passed, then
+                   the all the controller will use 6653 as their port number
             ptcp - ptcp number, This can be a string or a list that has
                    the same length as switch. This is optional and not required